==> haskell-binary-conduit-1.3.1-59-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.3.1
id: binary-conduit-1.3.1-Ja5r1mmJVJv4ihJdoG9VdT
key: binary-conduit-1.3.1-Ja5r1mmJVJv4ihJdoG9VdT
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
author: Alexander Vershilov
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
abi: 180c0b403dd03fd3812a463254d1ce33
exposed: True
exposed-modules:
    Data.Conduit.Serialization.Binary
import-dirs: /usr/lib/ghc-8.6.5/site-local/binary-conduit-1.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/binary-conduit-1.3.1
hs-libraries: HSbinary-conduit-1.3.1-Ja5r1mmJVJv4ihJdoG9VdT
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    conduit-1.3.1.1-F2avdKCTYaGL08mnA41Iqz
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-conduit-1.3.1-60-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.3.1
id: binary-conduit-1.3.1-5xVLD1ex5xYJqheqTsAg44
key: binary-conduit-1.3.1-5xVLD1ex5xYJqheqTsAg44
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
author: Alexander Vershilov
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
abi: ddf85881bf8349875abceb5356d61b78
exposed: True
exposed-modules:
    Data.Conduit.Serialization.Binary
import-dirs: /usr/lib/ghc-8.6.5/site-local/binary-conduit-1.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/binary-conduit-1.3.1
hs-libraries: HSbinary-conduit-1.3.1-5xVLD1ex5xYJqheqTsAg44
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    conduit-1.3.1.1-4WoHy8vBnBFBnZww6g0450
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
